Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Serve ¶
Serve execute Queries and provide their answer as channel-in-channel. Cancel the given context to stop the clockwork. Use NewQuery to create the requests in a way to avoid goroutine leaks. The internal cache table evicts entries older than 12h.
Types ¶
type Query ¶
Query holds what's the target that the ipwhoisserver should investigate for country ownership.
Source Files
¶
- server.go
Click to show internal directories.
Click to hide internal directories.